use std::collections::BTreeSet;

use proto::{LockModelBin, UnlockData};

#[derive(Default)]
pub struct LockModel {
    unlock_list: BTreeSet<i32>,
}

impl LockModel {
    pub fn from_bin(bin: LockModelBin) -> Self {
        Self {
            unlock_list: bin.unlock_list.into_iter().collect(),
        }
    }

    pub fn to_bin(&self) -> LockModelBin {
        LockModelBin {
            unlock_list: self.unlock_list.clone().into_iter().collect(),
        }
    }

    pub fn to_client(&self) -> UnlockData {
        UnlockData {
            unlock_id_list: self.unlock_list.clone().into_iter().collect(),
            ..Default::default()
        }
    }

    pub fn add_unlock(&mut self, id: i32) {
        self.unlock_list.insert(id);
    }

    pub fn is_unlock(&self, id: i32) -> bool {
        self.unlock_list.contains(&id)
    }
}
